==> enterprisemodules-wls_config-3.13.2.tar.gz: enterprisemodules-wls_config-3.13.2/lib/puppet/provider/wls_exec/wlst.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type/helpers'
require 'fileutils'
require 'puppet_x/enterprisemodules/weblogic/core'
require 'puppet_x/enterprisemodules/indent'

Puppet::Type.type(:wls_exec).provide(:sqlplus) do
  include EasyType::Helpers
  include EasyType::Template
  include Puppet_X::EnterpriseModules::WebLogic::Access

  confine :exists => '/etc/wls_setting.yaml'
  confine :feature => :weblogic_running

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'

    execute
  end

  def execute
    domain     = resource[:domain]
    cwd        = resource[:cwd]
    statement  = resource[:statement]
    #
    # First fo to the specified working dirctory if specified
    #
    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)

    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    #
    # If the statement start's with a @, it is a script. The content will be executed
    #
    if is_script?(statement)
      file_name = statement.split('@').last
      fail "File #{file_name} doesn't exist. " unless File.exist?(file_name)

      statement = File.read(file_name)
    end

    statement = statement.indent(2)
    environment = { 'action' => 'execute', 'type' => 'wls_exec' }
    output = wlst template('wls_config/wls_exec/execute.py.erb', binding), environment
    Puppet.debug(output) if resource.logoutput.to_s == 'true'
  end

  private

  # rubocop:disable Naming/PredicateName
  def is_script?(statement)
    statement[0] == '@'
  end
  # rubocop:enable Naming/PredicateName
end

==> enterprisemodules-wls_config-3.14.0.tar.gz: enterprisemodules-wls_config-3.14.0/lib/puppet/provider/wls_exec/wlst.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type/helpers'
require 'fileutils'
require 'puppet_x/enterprisemodules/weblogic/core'
require 'puppet_x/enterprisemodules/indent'

Puppet::Type.type(:wls_exec).provide(:sqlplus) do
  include EasyType::Helpers
  include EasyType::Template
  include Puppet_X::EnterpriseModules::WebLogic::Access

  confine :exists => '/etc/wls_setting.yaml'
  confine :feature => :weblogic_running

  mk_resource_methods

  def flush
    return if resource[:refreshonly].to_s == 'true'

    execute
  end

  def execute
    domain     = resource[:domain]
    cwd        = resource[:cwd]
    statement  = resource[:statement]
    #
    # First fo to the specified working dirctory if specified
    #
    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)

    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    #
    # If the statement start's with a @, it is a script. The content will be executed
    #
    if is_script?(statement)
      file_name = statement.split('@').last
      fail "File #{file_name} doesn't exist. " unless File.exist?(file_name)

      statement = File.read(file_name)
    end

    statement = statement.indent(2)
    environment = { 'action' => 'execute', 'type' => 'wls_exec' }
    output = wlst template('wls_config/wls_exec/execute.py.erb', binding), environment
    if resource.logoutput.to_s == 'true'
      output.split("\n").each { |line| log(line) }
    else
      Puppet.debug output
    end
  end

  private

  # rubocop:disable Naming/PredicateName
  def is_script?(statement)
    statement[0] == '@'
  end
  # rubocop:enable Naming/PredicateName
end
